import {
  transformHoistStatic
} from "./chunk-6BNVRGUN.mjs";
import {
  SETUP_SFC_REGEX,
  hotUpdateSetupSFC,
  transfromSetupSFC
} from "./chunk-UEGCJWCK.mjs";
import {
  hotUpdateSetupComponent,
  loadSetupComponent,
  transformSetupComponent
} from "./chunk-2GKUNBRP.mjs";
import {
  SETUP_COMPONENT_ID_REGEX
} from "./chunk-TDQQ5URA.mjs";
import {
  transformDefineModel
} from "./chunk-MREMRWUP.mjs";

// src/index.ts
import { createUnplugin } from "unplugin";
import { createFilter } from "@rollup/pluginutils";
import { getPackageInfoSync } from "local-pkg";
import { transform as transformDefineOptions } from "unplugin-vue-define-options";
import {
  finalizeContext,
  getTransformResult,
  initContext
} from "@vue-macros/common";
function resolveOption(options) {
  let version = options.version;
  if (version === void 0) {
    const vuePkg = getPackageInfoSync("vue");
    if (vuePkg) {
      version = +vuePkg.version.slice(0, 1);
    } else {
      version = 3;
    }
  }
  const setupComponent = options.setupComponent === false ? false : [/\.[cm]?[jt]sx?/];
  const setupSFC = options.setupSFC === false ? false : [SETUP_SFC_REGEX];
  return {
    include: [/\.vue$/],
    defineOptions: true,
    defineModel: true,
    hoistStatic: true,
    root: process.cwd(),
    ...options,
    version,
    setupComponent,
    setupSFC
  };
}
var name = "unplugin-vue-macros";
function transformVueSFC(code, id, options) {
  const { ctx, getMagicString } = initContext(code, id);
  if (options.hoistStatic)
    transformHoistStatic(ctx);
  if (options.defineOptions)
    transformDefineOptions(ctx);
  if (options.defineModel)
    transformDefineModel(ctx, options.version);
  finalizeContext(ctx);
  return getTransformResult(getMagicString(), id);
}
var src_default = createUnplugin((userOptions = {}) => {
  const options = resolveOption(userOptions);
  const filterSFC = createFilter(options.include, options.exclude);
  const filterSetupComponent = options.setupComponent ? createFilter(options.setupComponent) : void 0;
  const filterSetupSFC = options.setupSFC ? createFilter(options.setupSFC) : void 0;
  const setupComponentContext = {};
  return {
    name,
    transformInclude(id) {
      if (filterSetupSFC == null ? void 0 : filterSetupSFC(id))
        return true;
      if (filterSetupComponent == null ? void 0 : filterSetupComponent(id))
        return true;
      return filterSFC(id);
    },
    resolveId: options.setupComponent ? (id) => {
      if (SETUP_COMPONENT_ID_REGEX.test(id))
        return id;
    } : void 0,
    load: options.setupComponent ? (id) => {
      if (SETUP_COMPONENT_ID_REGEX.test(id))
        return loadSetupComponent(id, setupComponentContext, options.root);
    } : void 0,
    transform(code, id) {
      try {
        if (filterSetupSFC == null ? void 0 : filterSetupSFC(id)) {
          code = transfromSetupSFC(code, id).toString();
          const result = transformVueSFC(code, id, options);
          return result || code;
        } else if (filterSFC(id)) {
          return transformVueSFC(code, id, options);
        } else if (filterSetupComponent == null ? void 0 : filterSetupComponent(id)) {
          return transformSetupComponent(code, id, setupComponentContext);
        }
      } catch (err) {
        this.error(`${name} ${err}`);
      }
    },
    vite: {
      config: options.setupSFC ? () => {
        if (options.setupSFC)
          return {
            esbuild: {
              exclude: options.setupSFC
            }
          };
      } : void 0,
      configResolved(config) {
        options.root = config.root;
      },
      handleHotUpdate: filterSetupSFC || filterSetupComponent ? (ctx) => {
        if (filterSetupSFC == null ? void 0 : filterSetupSFC(ctx.file))
          return hotUpdateSetupSFC(ctx, filterSetupSFC);
        else if (filterSetupComponent == null ? void 0 : filterSetupComponent(ctx.file))
          return hotUpdateSetupComponent(ctx, setupComponentContext);
      } : void 0
    }
  };
});

export {
  src_default
};
