// src/setup-sfc/index.ts
import { MagicString, babelParse, getLang } from "@vue-macros/common";
var SETUP_SFC_REGEX = /\.setup\.[cm]?[jt]sx?$/;
var transfromSetupSFC = (code, id) => {
  const lang = getLang(id);
  const program = babelParse(code, lang);
  const s = new MagicString(code);
  for (const stmt of program.body) {
    if (stmt.type !== "ExportDefaultDeclaration")
      continue;
    if (!["FunctionExpression", "ArrowFunctionExpression"].includes(
      stmt.declaration.type
    ))
      throw new SyntaxError(`Default export must be a function`);
    s.append(`defineOptions({
  render: ${s.sliceNode(stmt.declaration)}
});`);
    s.removeNode(stmt);
  }
  const attrs = `${lang ? ` lang="${lang}"` : ""}`;
  s.prependRight(0, `<script setup${attrs}>
`);
  s.append(`
<\/script>`);
  return s;
};
var hotUpdateSetupSFC = ({ modules }, filter) => {
  function isSubModule(id) {
    const [filename, query] = id.split("?");
    if (!query)
      return false;
    if (!filter(filename))
      return false;
    return true;
  }
  const affectedModules = modules.filter((mod) => mod.id && isSubModule(mod.id));
  return affectedModules;
};

export {
  SETUP_SFC_REGEX,
  transfromSetupSFC,
  hotUpdateSetupSFC
};
